@@ -419,7 +419,7 @@ class DragonGather(TaskScheduler):
         get_lst = {'user': 'admin',
                    'group': 'admin',
                    'command': {'action': 'GET_LST',
-                               'varname': 'DBNAME'}}
+                               'varname': 'DBDATA'}}
         return get_lst
 
     def init_datawork_data(self):
