@@ -139,6 +139,7 @@ def start_datawork(env, conf="collector_example.json"):
     mq_code = data.get('MQ_CODE')
     mq_vhost = data.get('MQ_VHOST')
     mq_queue_name = data.get('MQ_QUEUE_NAME')
+    rdb_dbname = data.get('RDB_DBNAME', 'collector')
 
     print("Cantidad workers :", workers, type(workers))
      
@@ -208,7 +209,7 @@ def start_datawork(env, conf="collector_example.json"):
             'assigned_tasks': assigned_tasks,
             'rdb_address': tuple(map(data.get,("RDB_SOURCE_HOST", "RDB_SOURCE_PORT"))),
             'rdb_enu_address': tuple(map(data.get,("RDB_ENU_HOST", "RDB_ENU_PORT"))),
-            'rdb_dbname': 'collector',
+            'rdb_dbname': rdb_dbname,
             'chart': 'gnss_graph',
             'gui_set': gui_set,
             'gui_queue': gui_queue,
